@@ -1,4 +1,4 @@
-#  Copyright 2008-2012 Nokia Siemens Networks Oyj
+#  Copyright 2008-2015 Nokia Solutions and Networks
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -12,7 +12,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from robot.utils.setter import SetterAwareType
+from robotide.lib.robot.utils.setter import SetterAwareType
 
 
 class ModelObject(object):
@@ -24,3 +24,6 @@ class ModelObject(object):
 
     def __str__(self):
         return unicode(self).encode('ASCII', 'replace')
+
+    def __repr__(self):
+        return repr(str(self))
