@@ -1,4 +1,4 @@
-#  Copyright 2008-2012 Nokia Siemens Networks Oyj
+#  Copyright 2008-2015 Nokia Solutions and Networks
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -12,21 +12,21 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import with_statement
 import getopt     # optparse was not supported by Jython 2.2
 import os
 import re
 import sys
 import glob
 import string
-import codecs
 import textwrap
 
-from robot.errors import DataError, Information, FrameworkError
-from robot.version import get_full_version
+from robotide.lib.robot.errors import DataError, Information, FrameworkError
+from robotide.lib.robot.version import get_full_version
 
 from .misc import plural_or_not
-from .encoding import decode_output, decode_from_system, utf8open
+from .encoding import decode_output, decode_from_system
+from .utf8reader import Utf8Reader
+from .robottypes import is_integer, is_list_like, is_string
 
 
 ESCAPES = dict(
@@ -38,7 +38,7 @@ ESCAPES = dict(
 )
 
 
-class ArgumentParser:
+class ArgumentParser(object):
     _opt_line_re = re.compile('''
     ^\s{1,4}      # 1-4 spaces in the beginning of the line
     ((-\S\s)*)    # all possible short options incl. spaces (group 1)
@@ -48,8 +48,9 @@ class ArgumentParser:
     ''', re.VERBOSE)
 
     def __init__(self, usage, name=None, version=None, arg_limits=None,
-                 validator=None, auto_help=True, auto_version=True,
-                 auto_escape=True, auto_pythonpath=True, auto_argumentfile=True):
+                 validator=None, env_options=None, auto_help=True,
+                 auto_version=True, auto_escape=True, auto_pythonpath=True,
+                 auto_argumentfile=True):
         """Available options and tool name are read from the usage.
 
         Tool name is got from the first row of the usage. It is either the
@@ -67,21 +68,21 @@ class ArgumentParser:
         self._auto_escape = auto_escape
         self._auto_pythonpath = auto_pythonpath
         self._auto_argumentfile = auto_argumentfile
+        self._env_options = env_options
         self._short_opts = ''
         self._long_opts = []
         self._multi_opts = []
-        self._toggle_opts = []
-        self._names = []
+        self._flag_opts = []
         self._short_to_long = {}
         self._expected_args = ()
         self._create_options(usage)
 
-    def parse_args(self, args_list):
+    def parse_args(self, args):
         """Parse given arguments and return options and positional arguments.
 
         Arguments must be given as a list and are typically sys.argv[1:].
 
-        Options are retuned as a dictionary where long options are keys. Value
+        Options are returned as a dictionary where long options are keys. Value
         is a string for those options that can be given only one time (if they
         are given multiple times the last value is used) or None if the option
         is not used at all. Value for options that can be given multiple times
@@ -121,10 +122,12 @@ class ArgumentParser:
         amount of horizontal space as <---ESCAPES--->. Both help and version
         are wrapped to Information exception.
         """
-        args_list = [decode_from_system(a) for a in args_list]
+        if self._env_options:
+            args = os.getenv(self._env_options, '').split() + list(args)
+        args = [decode_from_system(a) for a in args]
         if self._auto_argumentfile:
-            args_list = self._process_possible_argfile(args_list)
-        opts, args = self._parse_args(args_list)
+            args = self._process_possible_argfile(args)
+        opts, args = self._parse_args(args)
         opts, args = self._handle_special_options(opts, args)
         self._arg_limit_validator(args)
         if self._validator:
@@ -153,7 +156,7 @@ class ArgumentParser:
         args = [self._lowercase_long_option(a) for a in args]
         try:
             opts, args = getopt.getopt(args, self._short_opts, self._long_opts)
-        except getopt.GetoptError, err:
+        except getopt.GetoptError as err:
             raise DataError(err.msg)
         return self._process_opts(opts), self._glob_args(args)
 
@@ -201,7 +204,7 @@ class ArgumentParser:
     def _unescape(self, value, escapes):
         if value in [None, True, False]:
             return value
-        if isinstance(value, list):
+        if is_list_like(value):
             return [self._unescape(item, escapes) for item in value]
         for esc_name, esc_value in escapes.items():
             if esc_name in value:
@@ -209,17 +212,28 @@ class ArgumentParser:
         return value
 
     def _process_opts(self, opt_tuple):
-        opts = self._init_opts()
+        opts = self._get_default_opts()
         for name, value in opt_tuple:
             name = self._get_name(name)
             if name in self._multi_opts:
                 opts[name].append(value)
-            elif name in self._toggle_opts:
-                opts[name] = not opts[name]
+            elif name in self._flag_opts:
+                opts[name] = True
+            elif name.startswith('no') and name[2:] in self._flag_opts:
+                opts[name[2:]] = False
             else:
                 opts[name] = value
         return opts
 
+    def _get_default_opts(self):
+        defaults = {}
+        for opt in self._long_opts:
+            opt = opt.rstrip('=')
+            if opt.startswith('no') and opt[2:] in self._flag_opts:
+                continue
+            defaults[opt] = [] if opt in self._multi_opts else None
+        return defaults
+
     def _glob_args(self, args):
         temp = []
         for path in args:
@@ -230,17 +244,6 @@ class ArgumentParser:
                 temp.append(path)
         return temp
 
-    def _init_opts(self):
-        opts = {}
-        for name in self._names:
-            if name in self._multi_opts:
-                opts[name] = []
-            elif name in self._toggle_opts:
-                opts[name] = False
-            else:
-                opts[name] = None
-        return opts
-
     def _get_name(self, name):
         name = name.lstrip('-')
         try:
@@ -258,11 +261,9 @@ class ArgumentParser:
                                     is_multi=bool(res.group(5)))
 
     def _create_option(self, short_opts, long_opt, takes_arg, is_multi):
-        if long_opt in self._names:
-            self._raise_option_multiple_times_in_usage('--' + long_opt)
-        self._names.append(long_opt)
+        self._verify_long_not_already_used(long_opt, not takes_arg)
         for sopt in short_opts:
-            if self._short_to_long.has_key(sopt):
+            if sopt in self._short_to_long:
                 self._raise_option_multiple_times_in_usage('-' + sopt)
             self._short_to_long[sopt] = long_opt
         if is_multi:
@@ -271,12 +272,24 @@ class ArgumentParser:
             long_opt += '='
             short_opts = [sopt+':' for sopt in short_opts]
         else:
-            self._toggle_opts.append(long_opt)
+            if long_opt.startswith('no'):
+                long_opt = long_opt[2:]
+            self._long_opts.append('no' + long_opt)
+            self._flag_opts.append(long_opt)
         self._long_opts.append(long_opt)
         self._short_opts += (''.join(short_opts))
 
+    def _verify_long_not_already_used(self, opt, flag=False):
+        if flag:
+            if opt.startswith('no'):
+                opt = opt[2:]
+            self._verify_long_not_already_used(opt)
+            self._verify_long_not_already_used('no' + opt)
+        elif opt in [o.rstrip('=') for o in self._long_opts]:
+            self._raise_option_multiple_times_in_usage('--' + opt)
+
     def _get_pythonpath(self, paths):
-        if isinstance(paths, basestring):
+        if is_string(paths):
             paths = [paths]
         temp = []
         for path in self._split_pythonpath(paths):
@@ -339,7 +352,7 @@ class ArgLimitValidator(object):
     def _parse_arg_limits(self, arg_limits):
         if arg_limits is None:
             return 0, sys.maxint
-        if isinstance(arg_limits, int):
+        if is_integer(arg_limits):
             return arg_limits, arg_limits
         if len(arg_limits) == 1:
             return arg_limits[0], sys.maxint
@@ -367,18 +380,23 @@ class ArgFileParser(object):
 
     def process(self, args):
         while True:
-            index = self._get_index(args)
-            if index < 0:
+            path, replace = self._get_index(args)
+            if not path:
                 break
-            path = args[index+1]
-            args[index:index+2] = self._get_args(path)
+            args[replace] = self._get_args(path)
         return args
 
     def _get_index(self, args):
         for opt in self._options:
-            if opt in args:
-                return args.index(opt)
-        return -1
+            start = opt + '=' if opt.startswith('--') else opt
+            for index, arg in enumerate(args):
+                # Handles `--argumentfile foo` and `-A foo`
+                if arg == opt and index + 1 < len(args):
+                    return args[index+1], slice(index, index+2)
+                # Handles `--argumentfile=foo` and `-Afoo`
+                if arg.startswith(start):
+                    return arg[len(start):], slice(index, index+1)
+        return None, -1
 
     def _get_args(self, path):
         if path.upper() != 'STDIN':
@@ -389,20 +407,14 @@ class ArgFileParser(object):
 
     def _read_from_file(self, path):
         try:
-            with utf8open(path) as f:
-                content = f.read()
-        except (IOError, UnicodeError), err:
+            with Utf8Reader(path) as reader:
+                return reader.read()
+        except (IOError, UnicodeError) as err:
             raise DataError("Opening argument file '%s' failed: %s"
                             % (path, err))
-        if content.startswith(codecs.BOM_UTF8.decode('UTF-8')):
-            content = content[1:]
-        return content
 
     def _read_from_stdin(self):
-        content = sys.__stdin__.read()
-        if sys.platform != 'cli':
-            content = decode_output(content)
-        return content
+        return decode_output(sys.__stdin__.read())
 
     def _process_file(self, content):
         args = []
