@@ -13,9 +13,16 @@
 #  limitations under the License.
 
 import wx
+import os
+import tempfile
+import uuid
+import atexit
+import glob
+import sys
 
 from robotide.pluginapi import Plugin, ActionInfo, RideLog
 from robotide import widgets
+from robotide import context
 
 
 def _message_to_string(msg):
@@ -26,9 +33,36 @@ class LogPlugin(Plugin):
     """Viewer for internal log messages."""
 
     def __init__(self, app):
-        Plugin.__init__(self, app, default_settings={'log_to_console': False})
+        Plugin.__init__(self, app, default_settings={
+            'log_to_console': False,
+            'log_to_file': True
+        })
         self._log = []
         self._window = None
+        self._path = os.path.join(
+            tempfile.gettempdir(), '{}-ride.log'.format(uuid.uuid4()))
+        self._outfile = None
+        self._remove_old_log_files()
+        atexit.register(self._close)
+
+    def _close(self):
+        if self._outfile is not None:
+            self._outfile.flush()
+            self._outfile.close()
+
+    def _remove_old_log_files(self):
+        for fname in glob.glob(
+                os.path.join(tempfile.gettempdir(), '*-ride.log')):
+            try:
+                os.remove(fname)
+            except OSError or IOError as e:
+                sys.stderr.write("{}".format(e))
+
+    @property
+    def _logfile(self):
+        if self._outfile is None:
+            self._outfile = open(self._path, 'w')
+        return self._outfile
 
     def enable(self):
         self._create_menu()
@@ -51,9 +85,12 @@ class LogPlugin(Plugin):
             self._window.update_log()
         if self.log_to_console:
             print _message_to_string(log_event)
+        if self.log_to_file:
+            self._logfile.write(_message_to_string(log_event))
         if log_event.notify_user:
-            widgets.HtmlDialog(
-                log_event.level, log_event.message, padding=10).Show()
+            font_size = 13 if context.IS_MAC else -1
+            widgets.HtmlDialog(log_event.level, log_event.message,
+                               padding=10, font_size=font_size).Show()
 
     def OnViewLog(self, event):
         if not self._window:
