@@ -20,23 +20,14 @@ import tempfile
 from itertools import chain
 
 from robotide import robotapi, utils
-from robotide.context import SYSLOG
-from robotide.namespace import variablefetcher, robotlibraryloader
-from robotide.namespace.cache import LibraryCache, ExpiringCache
-from robotide.namespace.resourcefactory import ResourceFactory
+from robotide.publish import PUBLISHER, RideSettingsChanged, RideLogMessage
+from robotide.robotapi import VariableFileSetter
 from robotide.spec.iteminfo import TestCaseUserKeywordInfo,\
     ResourceUserKeywordInfo, VariableInfo, _UserKeywordInfo, ArgumentInfo
-from robotide.namespace.embeddedargs import EmbeddedArgsHandler
-from robotide.publish import PUBLISHER, RideSettingsChanged
 
-
-installation_path = os.path.normpath(
-    os.path.join(os.path.dirname(os.path.abspath(__file__)), '..'))
-BUNDLED_LIBRARIES_PATH = os.path.join(
-    installation_path, 'lib', 'robot', 'libraries')
-REMOTE_LIB_PATH = os.path.join(
-    installation_path, 'spec', 'remote')
-del installation_path
+from .cache import LibraryCache, ExpiringCache
+from .resourcefactory import ResourceFactory
+from .embeddedargs import EmbeddedArgsHandler
 
 
 class Namespace(object):
@@ -60,25 +51,13 @@ class Namespace(object):
 
     def _set_pythonpath(self):
         """Add user configured paths to PYTHONAPATH.
-
-        In addition, if `use installaed robot libraries` setting is `True`, and
-        a Robot Framework installation is found, remove bundled RF libraries
-        from PYTHONAPATH and create spec files for the installed RF's standard
-        libraries.
         """
-        if self._settings['use installed robot libraries']:
-            rf_version = robotlibraryloader.find_installed_robot_libraries(
-                self._settings.get('installed robot version', None))
-            if rf_version is not None:
-                if BUNDLED_LIBRARIES_PATH in sys.path:
-                    sys.path.remove(BUNDLED_LIBRARIES_PATH)
-                    sys.path.append(REMOTE_LIB_PATH)
-                self._settings.set('installed robot version', rf_version)
         for path in self._settings.get('pythonpath', []):
             if path not in sys.path:
                 normalized = path.replace('/', os.sep)
                 sys.path.insert(0, normalized)
-                SYSLOG("Inserted '{0}' to sys.path.".format(normalized))
+                RideLogMessage(u'Inserted \'{0}\' to sys.path.'
+                               .format(normalized)).publish()
 
     def _setting_changed(self, message):
         section, setting = message.keys
@@ -131,15 +110,11 @@ class Namespace(object):
         ctx = self._context_factory.ctx_for_controller(controller)
         sugs = set()
         sugs.update(self._get_suggestions_from_hooks(datafile, start))
-        if self._blank(start) or self._looks_like_variable(start):
-            sugs.update(self._variable_suggestions(controller, start, ctx))
-        else:
-            sugs.update(self._variable_suggestions(controller, '${' + start,
-                                                   ctx))
-            sugs.update(self._variable_suggestions(controller, '@{' + start,
-                                                   ctx))
         if self._blank(start) or not self._looks_like_variable(start):
+            sugs.update(self._variable_suggestions(controller, start, ctx))
             sugs.update(self._keyword_suggestions(datafile, start, ctx))
+        else:
+            sugs.update(self._variable_suggestions(controller, start, ctx))
         sugs_list = list(sugs)
         sugs_list.sort()
         return sugs_list
@@ -157,18 +132,15 @@ class Namespace(object):
         return start == ''
 
     def _looks_like_variable(self, start):
-        return (len(start) == 1 and start.startswith('$') or
-                start.startswith('@')) \
-            or (len(start) >= 2 and start.startswith('${') or
-                start.startswith('@{'))
+        return len(start) == 1 and start[0] in ['$', '@', '&'] \
+            or (len(start) >= 2 and start[:2] in ['${', '@{', '&{'])
 
     def _variable_suggestions(self, controller, start, ctx):
-        datafile = controller.datafile
-        start_normalized = utils.normalize(start)
         self._add_kw_arg_vars(controller, ctx.vars)
-        variables = self._retriever.get_variables_from(datafile, ctx)
-        return (v for v in variables
-                if utils.normalize(v.name).startswith(start_normalized))
+        variables = self._retriever.get_variables_from(
+            controller.datafile, ctx)
+        sugs = (v for v in variables if v.name_matches(start))
+        return sugs
 
     def _add_kw_arg_vars(self, controller, variables):
         for name, value in controller.get_local_variables().iteritems():
@@ -176,9 +148,9 @@ class Namespace(object):
 
     def _keyword_suggestions(self, datafile, start, ctx):
         start_normalized = utils.normalize(start)
-        return (sug for sug in chain(
-            self._get_default_keywords(),
-            self._retriever.get_keywords_from(datafile, ctx))
+        all_kws = chain(self._get_default_keywords(),
+                        self._retriever.get_keywords_from(datafile, ctx))
+        return (sug for sug in all_kws
                 if sug.name_begins_with(start_normalized) or
                 sug.longname_begins_with(start_normalized))
 
@@ -262,11 +234,12 @@ class RetrieverContext(object):
         return self.vars.replace_variables(text)
 
     def allow_going_through_resources_again(self):
-        """Resets the parsed-cache.
+        """Resets the parsed resources cache.
+
         Normally all resources that have been handled are added to 'parsed' and
-        then not handled again, to prevent looping forever. If this same context
-        is used for going through the resources again, then you should call
-        this.
+        then not handled again, to prevent looping forever. If this same
+        context is used for going through the resources again, this method
+        should be called first.
         """
         self.parsed = set()
 
@@ -295,7 +268,7 @@ class _VariableStash(object):
         '${PREV_TEST_MESSAGE}': '',
         '${CURDIR}': '.',
         '${TEST_NAME}': '',
-        '@{TEST_TAGS}': '',
+        '@{TEST_TAGS}': [],
         '${TEST_STATUS}': '',
         '${TEST_MESSAGE}': '',
         '${SUITE_NAME}': '',
@@ -314,7 +287,7 @@ class _VariableStash(object):
 
     def set(self, name, value, source):
         self._vars[name] = value
-        self._sources[name] = source
+        self._sources[name[2:-1]] = source
 
     def set_argument(self, name, value):
         self.set(name, value, self.ARGUMENT_SOURCE)
@@ -326,24 +299,48 @@ class _VariableStash(object):
             return self._vars.replace_string(value, ignore_errors=True)
 
     def set_from_variable_table(self, variable_table):
+        reader = robotapi.VariableTableReader()
         for variable in variable_table:
             try:
-                if not self._vars.has_key(variable.name):
-                    _, value = self._vars._get_var_table_name_and_value(
-                        variable.name, variable.value,
-                        variable.report_invalid_syntax)
-                    self.set(variable.name, value, variable_table.source)
+                if variable.name not in self._vars.store:
+                    _, value = reader._get_name_and_value(
+                        variable.name,
+                        variable.value,
+                        variable.report_invalid_syntax
+                    )
+                    self.set(variable.name, value.resolve(self._vars),
+                             variable_table.source)
             except robotapi.DataError:
                 if robotapi.is_var(variable.name):
-                    self.set(variable.name, '', variable_table.source)
+                    val = self._empty_value_for_variable_type(variable.name)
+                    self.set(variable.name, val, variable_table.source)
+
+    def _empty_value_for_variable_type(self, name):
+        if name[0] == '$':
+            return ''
+        if name[0] == '@':
+            return []
+        return {}
 
     def set_from_file(self, varfile_path, args):
-        for item in variablefetcher.import_varfile(varfile_path, args):
-            self.set(*item)
+        vars_from_file = VariableFileSetter(None)._import_if_needed(
+            varfile_path, args)
+        for name, value in vars_from_file:
+            self.set(name, value, varfile_path)
+
+    def _get_prefix(self, value):
+        if utils.is_dict_like(value):
+            return '&'
+        elif utils.is_list_like(value):
+            return '@'
+        else:
+            return '$'
 
     def __iter__(self):
-        for name, value in self._vars.items():
+        for name, value in self._vars.store.data.items():
             source = self._sources[name]
+            prefix = self._get_prefix(value)
+            name = u'{0}{{{1}}}'.format(prefix, name)
             if source == self.ARGUMENT_SOURCE:
                 yield ArgumentInfo(name, value)
             else:
@@ -380,9 +377,10 @@ class DatafileRetriever(object):
     def get_keywords_from(self, datafile, ctx):
         self._get_vars_recursive(datafile, ctx)
         ctx.allow_going_through_resources_again()
-        return sorted(set(self._get_datafile_keywords(datafile) +\
-              self._get_imported_resource_keywords(datafile, ctx) +\
-              self._get_imported_library_keywords(datafile, ctx)))
+        return sorted(set(
+            self._get_datafile_keywords(datafile) +
+            self._get_imported_resource_keywords(datafile, ctx) +
+            self._get_imported_library_keywords(datafile, ctx)))
 
     def is_library_import_ok(self, datafile, imp, ctx):
         self._get_vars_recursive(datafile, ctx)
@@ -487,7 +485,8 @@ class DatafileRetriever(object):
         kws.update(datafile.keywords)
         kws_from_res = self._collect_each_res_import(
             datafile, ctx,
-            lambda res, ctx, kws: kws.update(self._get_user_keywords_recursive(res, ctx)))
+            lambda res, ctx, kws:
+                kws.update(self._get_user_keywords_recursive(res, ctx)))
         kws.update(kws_from_res)
         return kws
 
@@ -513,7 +512,6 @@ class DatafileRetriever(object):
         resources.update(res)
         for child in datafile.children:
             resources.update(self.get_resources_from(child))
-
         return resources
 
     def _add_resource(self, res, ctx, items):
@@ -535,8 +533,9 @@ class _Keywords(object):
             self._add_keyword(kw)
 
     def _add_keyword(self, kw):
-        # TODO: this hack creates a preference for local keywords over resources and libraries
-        # Namespace should be rewritten to handle keyword preference order
+        # TODO: this hack creates a preference for local keywords over
+        # resources and libraries Namespace should be rewritten to handle
+        # keyword preference order
         if kw.name not in self.keywords:
             self.keywords[kw.name] = kw
             self._add_embedded(kw)
