@@ -15,7 +15,7 @@
 import os
 import shutil
 
-from robotide.context import SETTINGS_DIRECTORY
+from robotide.context import SETTINGS_DIRECTORY, LIBRARY_XML_DIRECTORY
 from robotide.preferences.configobj import ConfigObj, ConfigObjError,\
     Section, UnreprError
 from robotide.preferences import excludes
@@ -89,9 +89,8 @@ class SettingsMigrator(object):
             self.migrate_from_5_to_6(self._old_settings)
         if self._old_settings.get(self.SETTINGS_VERSION) == 6:
             self.migrate_from_6_to_7(self._old_settings)
-        # so next would be something like:
-        # if self._old_settings[self.SETTINGS_VERSION] == 6:
-        #   self.migrate_from_7_to_8(self._old_settings)
+        if self._old_settings.get(self.SETTINGS_VERSION) == 7:
+            self.migrate_from_7_to_8(self._old_settings)
         self.merge()
 
     def merge(self):
@@ -164,6 +163,20 @@ class SettingsMigrator(object):
         settings['use installed robot libraries'] = True
         settings[self.SETTINGS_VERSION] = 7
 
+    def migrate_from_7_to_8(self, settings):
+        installed_rf_libs = settings.get('use installed robot libraries', None)
+        if installed_rf_libs:
+            del settings['use installed robot libraries']
+            for name in [
+                'BuiltIn', 'Collections', 'DateTime', 'Dialogs', 'Easter',
+                'OperatingSystem', 'Process', 'Remote',
+                'Screenshot', 'String', 'Telnet', 'XML']:
+                lib_xml_path = os.path.join(LIBRARY_XML_DIRECTORY,
+                                            '{}.xml'.format(name))
+                if os.path.exists(lib_xml_path):
+                    os.remove(lib_xml_path)
+        settings[self.SETTINGS_VERSION] = 8
+
     def _write_merged_settings(self, settings, path):
         try:
             with open(path, 'wb') as outfile:
